@@ -85,8 +85,9 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 	}
 
 	protected IASTName findName(String section, int len, boolean preferImplicitName) {
-		if (len == 0)
-			len= section.length();
+		if (len <= 0)
+			len += section.length();
+
 		for (int i = 0; i < strategy.getAstCount(); i++) {
 			IASTTranslationUnit ast = strategy.getAst(i);
 			final IASTNodeSelector nodeSelector = ast.getNodeSelector(null);
@@ -102,7 +103,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 				}
 			}
 		}
-	
+
 		return null;
 	}
 	
@@ -128,14 +129,14 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 	 * @param clazz an expected class type or interface that the binding should extend/implement
 	 * @return the associated name's binding
 	 */
-	protected <T> T getBindingFromASTName(String section, int len, Class<T> clazz, Class ... cs) {
-		if (len < 1) {
-			len= section.length()+len;
-		}
+	protected <T> T getBindingFromASTName(String section, int len, Class<T> clazz, Class... cs) {
+		if (len <= 0)
+			len += section.length();
+
 		IASTName name= findName(section, len);
 		assertNotNull("Name not found for \"" + section + "\"", name);
 		assertEquals(section.substring(0, len), name.getRawSignature());
-	
+
 		IBinding binding = name.resolveBinding();
 		assertNotNull("No binding for " + name.getRawSignature(), binding);
 		assertFalse("Binding is a ProblemBinding for name \"" + name.getRawSignature() + "\"", IProblemBinding.class.isAssignableFrom(name.resolveBinding().getClass()));
@@ -156,10 +157,10 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 	 * @param clazz an expected class type or interface that the binding should extend/implement
 	 * @return the associated implicit name's binding
 	 */
-	protected <T> T getBindingFromImplicitASTName(String section, int len, Class<T> clazz, Class ... cs) {
-		if (len < 1) {
-			len= section.length()+len;
-		}
+	protected <T> T getBindingFromImplicitASTName(String section, int len, Class<T> clazz, Class... cs) {
+		if (len <= 0)
+			len += section.length();
+
 		IASTName name= findImplicitName(section, len);
 		assertNotNull("Name not found for \"" + section + "\"", name);
 		assertEquals(section.substring(0, len), name.getRawSignature());
@@ -172,22 +173,30 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 	}
 
 	/*
-	 * @see IndexBindingResolutionTestBase#getBindingFromASTName(String, int, Class<T>, Class ...)
+	 * @see IndexBindingResolutionTestBase#getBindingFromASTName(String, int, Class<T>, Class...)
 	 */
 	protected <T extends IBinding> T getBindingFromASTName(String section, int len) {
 		if (len <= 0)
 			len += section.length();
-	
+
 		IASTName name= findName(section, len);
 		assertNotNull("Name not found for \"" + section + "\"", name);
 		assertEquals(section.substring(0, len), name.getRawSignature());
-	
+
 		IBinding binding = name.resolveBinding();
 		assertNotNull("No binding for " + name.getRawSignature(), binding);
 		assertFalse("Binding is a ProblemBinding for name \"" + name.getRawSignature() + "\"", IProblemBinding.class.isAssignableFrom(name.resolveBinding().getClass()));
 		return (T) binding;
 	}
-	
+
+	protected <T extends IBinding> T getBindingFromFirstIdentifier(String section) {
+		return getBindingFromASTName(section, getIdentifierLength(section));
+	}
+
+	protected <T extends IBinding> T getBindingFromFirstIdentifier(String section, Class<T> clazz, Class... cs) {
+		return getBindingFromASTName(section, getIdentifierLength(section), clazz, cs);
+	}
+
 	/*
 	 * @see IndexBindingResolutionTestBase#getBindingFromImplicitASTName(String, int, Class<T>, Class ...)
 	 */
@@ -201,7 +210,8 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 
 		IBinding binding = name.resolveBinding();
 		assertNotNull("No binding for " + name.getRawSignature(), binding);
-		assertFalse("Binding is a ProblemBinding for name \"" + name.getRawSignature() + "\"", IProblemBinding.class.isAssignableFrom(name.resolveBinding().getClass()));
+		assertFalse("Binding is a ProblemBinding for name \"" + name.getRawSignature() + "\"",
+				IProblemBinding.class.isAssignableFrom(name.resolveBinding().getClass()));
 		return (T) binding;
 	}
 
@@ -215,13 +225,18 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		IASTName name= findName(section, len);
 		assertNotNull("Name not found for \"" + section + "\"", name);
 		assertEquals(section.substring(0, len), name.getRawSignature());
-	
+
 		IBinding binding = name.resolveBinding();
 		assertNotNull("No binding for " + name.getRawSignature(), binding);
-		assertTrue("Binding is not a ProblemBinding for name \"" + name.getRawSignature() + "\"", IProblemBinding.class.isAssignableFrom(name.resolveBinding().getClass()));
+		assertTrue("Binding is not a ProblemBinding for name \"" + name.getRawSignature() + "\"",
+				IProblemBinding.class.isAssignableFrom(name.resolveBinding().getClass()));
 		return name.resolveBinding();
 	}
 
+	protected IBinding getProblemFromFirstIdentifier(String section) {
+		return getProblemFromASTName(section, getIdentifierLength(section));
+	}
+
 	protected static void assertQNEquals(String expectedQN, IBinding b) {
 		assertInstance(b, IBinding.class);
 		if (b instanceof ICPPBinding) {
@@ -300,7 +315,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 	final protected void checkBindings() throws Exception {
 		for (int i = 0; i < strategy.getAstCount(); i++) {
 			IASTTranslationUnit ast = strategy.getAst(i);
-			CNameCollector col = new CNameCollector();
+			NameCollector col = new NameCollector();
 			ast.accept(col);
 			for (IASTName n : col.nameList) {
 				assertFalse("ProblemBinding for " + n.getRawSignature(), n.resolveBinding() instanceof IProblemBinding);
@@ -308,7 +323,14 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		}
 	}
 
-	static protected class CNameCollector extends ASTVisitor {
+	protected int getIdentifierLength(String str) {
+		int i;
+		for (i = 0; i < str.length() && Character.isJavaIdentifierPart(str.charAt(i)); ++i) {
+		}
+		return i;
+	}
+
+	static protected class NameCollector extends ASTVisitor {
         {
             shouldVisitNames = true;
         }
@@ -325,13 +347,13 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
                 return null;
             return nameList.get(idx);
         }
-       
+
         public int size() {
         	return nameList.size();
         }
     }
 
-	interface ITestStrategy {
+	protected interface ITestStrategy {
 		IIndex getIndex();
 		void setUp() throws Exception;
 		void tearDown() throws Exception;
@@ -358,7 +380,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		public ICProject getCProject() {
 			return cproject;
 		}
-	
+
 		@Override
 		public StringBuilder[] getTestData() {
 			return testData;
@@ -423,7 +445,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		public IIndex getIndex() {
 			return index;
 		}
-	
+
 		@Override
 		public boolean isCompositeIndex() {
 			return false;
@@ -484,7 +506,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 
 			IFile cppfile= TestSourceReader.createFile(cproject.getProject(), new Path("references.c" + (cpp ? "pp" : "")), testData[1].toString());
 	        waitForIndexer(cproject);
-		
+
 			if (DEBUG) {
 				System.out.println("Project PDOM: " + getName());
 				((PDOM) CCoreInternals.getPDOMManager().getPDOM(cproject)).accept(new PDOMPrettyPrinter());
@@ -510,7 +532,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		public IIndex getIndex() {
 			return index;
 		}
-	
+
 		@Override
 		public boolean isCompositeIndex() {
 			return false;
@@ -525,7 +547,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 	 * to put the contents of the section to. To request the AST of a file, put an asterisk after
 	 * the file name.
 	 */
-	class SinglePDOMTestNamedFilesStrategy implements ITestStrategy {
+	protected class SinglePDOMTestNamedFilesStrategy implements ITestStrategy {
 		private IIndex index;
 		private ICProject cproject;
 		private StringBuilder[] testData;
@@ -594,7 +616,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 			}
 			CCorePlugin.getIndexManager().setIndexerId(cproject, IPDOMManager.ID_FAST_INDEXER);
 	        waitForIndexer(cproject);
-		
+
 			if (DEBUG) {
 				System.out.println("Project PDOM: " + getName());
 				((PDOM) CCoreInternals.getPDOMManager().getPDOM(cproject)).accept(new PDOMPrettyPrinter());
@@ -622,7 +644,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		public IIndex getIndex() {
 			return index;
 		}
-	
+
 		@Override
 		public boolean isCompositeIndex() {
 			return false;
@@ -644,7 +666,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		public ICProject getCProject() {
 			return cproject;
 		}
-	
+
 		@Override
 		public void tearDown() throws Exception {
 			if (index != null) {
@@ -678,7 +700,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 			IndexerPreferences.set(cproject.getProject(), IndexerPreferences.KEY_INDEXER_ID, IPDOMManager.ID_FAST_INDEXER);
 			CCorePlugin.getIndexManager().reindex(cproject);
 			waitForIndexer(cproject);
-		
+
 			if (DEBUG) {
 				System.out.println("Online: "+getName());
 			 	((PDOM) CCoreInternals.getPDOMManager().getPDOM(cproject)).accept(new PDOMPrettyPrinter());
@@ -695,17 +717,17 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 					CProjectHelper.createCProject("ReferencedContent" + System.currentTimeMillis(), "bin", IPDOMManager.ID_NO_INDEXER);
 			String content = testData[0].toString();
 			IFile file = TestSourceReader.createFile(referenced.getProject(), new Path("header.h"), content);
-		
+
 			IndexerPreferences.set(referenced.getProject(), IndexerPreferences.KEY_INDEXER_ID, IPDOMManager.ID_FAST_INDEXER);
 			CCorePlugin.getIndexManager().reindex(referenced);
-		
+
 			waitForIndexer(referenced);
-		
+
 			if (DEBUG) {
 				System.out.println("Referenced: "+getName());
 				((PDOM) CCoreInternals.getPDOMManager().getPDOM(referenced)).accept(new PDOMPrettyPrinter());
 			}
-		
+
 			return referenced;
 		}
 
@@ -737,7 +759,7 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 		public StringBuilder[] getTestData() {
 			return testData;
 		}
-	
+
 		@Override
 		public boolean isCompositeIndex() {
 			return true;
@@ -767,4 +789,11 @@ public abstract class IndexBindingResolutionTestBase extends BaseTestCase {
 			fail("Artificially failing - see IndexBindingResolutionTestBase.fakeFailForReferenced()");
 		}
 	}
+	
+	protected static void assertSameType(IType first, IType second){
+		assertNotNull(first);
+		assertNotNull(second);
+		assertTrue("Expected types to be the same, but first was: '" + first.toString() +
+				"' and second was: '" + second + "'", first.isSameType(second));
+	}
 }
