@@ -21,6 +21,7 @@ import java.util.Set;
 
 import org.eclipse.cdt.core.CCorePlugin;
 import org.eclipse.cdt.core.language.settings.providers.ICListenerAgent;
+import org.eclipse.cdt.core.language.settings.providers.ILanguageSettingsBroadcastingProvider;
 import org.eclipse.cdt.core.language.settings.providers.ILanguageSettingsChangeEvent;
 import org.eclipse.cdt.core.language.settings.providers.ILanguageSettingsChangeListener;
 import org.eclipse.cdt.core.language.settings.providers.ILanguageSettingsEditableProvider;
@@ -34,7 +35,6 @@ import org.eclipse.cdt.core.settings.model.ICConfigurationDescription;
 import org.eclipse.cdt.core.settings.model.ICLanguageSettingEntry;
 import org.eclipse.cdt.core.settings.model.ICProjectDescription;
 import org.eclipse.cdt.core.settings.model.ICSettingEntry;
-import org.eclipse.cdt.core.settings.model.ICStorageElement;
 import org.eclipse.cdt.internal.core.XmlUtil;
 import org.eclipse.cdt.internal.core.settings.model.CConfigurationSpecSettings;
 import org.eclipse.cdt.internal.core.settings.model.IInternalCCfgInfo;
@@ -482,11 +482,11 @@ public class LanguageSettingsProvidersSerializer {
 	/**
 	 * Compute events for language settings changes in workspace.
 	 */
-	private static List<LanguageSettingsChangeEvent> createLanguageSettingsChangeEvents(List<LanguageSettingsSerializableProvider> providers) {
+	private static List<LanguageSettingsChangeEvent> createLanguageSettingsChangeEvents(List<ILanguageSettingsBroadcastingProvider> providers) {
 		List<LanguageSettingsChangeEvent> events = new ArrayList<LanguageSettingsChangeEvent>();
 
 		List<String> providerIds = new ArrayList<String>();
-		for (LanguageSettingsSerializableProvider provider : providers) {
+		for (ILanguageSettingsBroadcastingProvider provider : providers) {
 			providerIds.add(provider.getId());
 		}
 
@@ -521,23 +521,27 @@ public class LanguageSettingsProvidersSerializer {
 	 */
 	public static void serializeLanguageSettingsWorkspace() throws CoreException {
 		URI uriStoreWsp = getStoreInWorkspaceArea(STORAGE_WORKSPACE_LANGUAGE_SETTINGS);
-		List<LanguageSettingsSerializableProvider> serializableWorkspaceProviders = new ArrayList<LanguageSettingsSerializableProvider>();
+		List<ILanguageSettingsBroadcastingProvider> broadcastingWorkspaceProviders = new ArrayList<ILanguageSettingsBroadcastingProvider>();
+		List<LanguageSettingsSerializableProvider> serializingWorkspaceProviders = new ArrayList<LanguageSettingsSerializableProvider>();
 		for (ILanguageSettingsProvider provider : rawGlobalWorkspaceProviders.values()) {
+			if (provider instanceof ILanguageSettingsBroadcastingProvider) {
+				broadcastingWorkspaceProviders.add((ILanguageSettingsBroadcastingProvider)provider);
+			}
 			if (provider instanceof LanguageSettingsSerializableProvider) {
 				if (!LanguageSettingsManager.isEqualExtensionProvider(provider, true)) {
-					serializableWorkspaceProviders.add((LanguageSettingsSerializableProvider)provider);
+					serializingWorkspaceProviders.add((LanguageSettingsSerializableProvider)provider);
 				}
 			}
 		}
 		try {
 			List<LanguageSettingsChangeEvent> events = null;
-			if (serializableWorkspaceProviders.isEmpty()) {
+			if (serializingWorkspaceProviders.isEmpty()) {
 				java.io.File fileStoreWsp = new java.io.File(uriStoreWsp);
 				try {
 					serializingLockWsp.acquire();
 					fileStoreWsp.delete();
 					// manufacture events while inside the lock
-					events = createLanguageSettingsChangeEvents(serializableWorkspaceProviders);
+					events = createLanguageSettingsChangeEvents(broadcastingWorkspaceProviders);
 				} finally {
 					serializingLockWsp.release();
 				}
@@ -547,7 +551,7 @@ public class LanguageSettingsProvidersSerializer {
 				Element elementExtension = XmlUtil.appendElement(rootElement, ELEM_EXTENSION,
 						new String[] {ATTR_EXTENSION_POINT, PROVIDER_EXTENSION_POINT_ID});
 
-				for (LanguageSettingsSerializableProvider provider : serializableWorkspaceProviders) {
+				for (LanguageSettingsSerializableProvider provider : serializingWorkspaceProviders) {
 					provider.serialize(elementExtension);
 				}
 
@@ -555,7 +559,7 @@ public class LanguageSettingsProvidersSerializer {
 					serializingLockWsp.acquire();
 					XmlUtil.serializeXml(doc, uriStoreWsp);
 					// manufacture events while inside the lock
-					events = createLanguageSettingsChangeEvents(serializableWorkspaceProviders);
+					events = createLanguageSettingsChangeEvents(broadcastingWorkspaceProviders);
 				} finally {
 					serializingLockWsp.release();
 				}
@@ -784,7 +788,7 @@ public class LanguageSettingsProvidersSerializer {
 
 			String[] defaultIds = ((ILanguageSettingsProvidersKeeper) cfgDescription).getDefaultLanguageSettingsProvidersIds();
 			if (defaultIds == null) {
-				defaultIds = new String[0];
+				defaultIds = ScannerDiscoveryLegacySupport.getDefaultProviderIdsLegacy(cfgDescription);
 			}
 
 			// check size
@@ -829,11 +833,6 @@ public class LanguageSettingsProvidersSerializer {
 		try {
 			// Add the storage module to .cpoject and persist on disk as a side effect of adding
 			prjDescription.getStorage(CPROJECT_STORAGE_MODULE_LANGUAGE_SETTINGS_PROVIDERS, true);
-			if (!ScannerDiscoveryLegacySupport.isLanguageSettingsProvidersFunctionalityDefined(project)) {
-				// set the flag if was not previously set by the user - to the default value
-				ScannerDiscoveryLegacySupport.setLanguageSettingsProvidersFunctionalityEnabled(project,
-						ScannerDiscoveryLegacySupport.isLanguageSettingsProvidersFunctionalityEnabled(project));
-			}
 		} catch (CoreException e) {
 			CCorePlugin.log("Internal error while trying to serialize language settings", e); //$NON-NLS-1$
 		}
@@ -1131,7 +1130,6 @@ public class LanguageSettingsProvidersSerializer {
 		IProject project = prjDescription.getProject();
 		IFile storeInPrjArea = getStoreInProjectArea(project);
 		boolean isStoreInProjectAreaExist = storeInPrjArea.exists();
-		boolean enableLSP = isStoreInProjectAreaExist;
 		if (isStoreInProjectAreaExist) {
 			Document doc = null;
 			try {
@@ -1156,17 +1154,8 @@ public class LanguageSettingsProvidersSerializer {
 			} catch (Exception e) {
 				CCorePlugin.log("Can't load preferences from file " + storeInPrjArea.getLocation(), e); //$NON-NLS-1$
 			}
-
-		} else { // Storage in project area does not exist
-			ICStorageElement lspStorageModule = null;
-			try {
-				lspStorageModule = prjDescription.getStorage(CPROJECT_STORAGE_MODULE_LANGUAGE_SETTINGS_PROVIDERS, false);
-			} catch (CoreException e) {
-				String msg = "Internal error while trying to load language settings"; //$NON-NLS-1$
-				CCorePlugin.log(msg, e);
-			}
-
-			// set default providers defined in the tool-chain
+		} else {
+			// If storage in project area does not exist set default providers defined in the tool-chain
 			for (ICConfigurationDescription cfgDescription : prjDescription.getConfigurations()) {
 				if (cfgDescription instanceof ILanguageSettingsProvidersKeeper) {
 					String[] ids = ((ILanguageSettingsProvidersKeeper) cfgDescription).getDefaultLanguageSettingsProvidersIds();
@@ -1183,15 +1172,10 @@ public class LanguageSettingsProvidersSerializer {
 					}
 				}
 			}
-
-			enableLSP = lspStorageModule != null;
-		}
-
-		if (!ScannerDiscoveryLegacySupport.isLanguageSettingsProvidersFunctionalityDefined(project)) {
-			// set the flag if was not previously set by the user
-			ScannerDiscoveryLegacySupport.setLanguageSettingsProvidersFunctionalityEnabled(project, enableLSP);
 		}
 
+		// propagate the preference to project properties
+		ScannerDiscoveryLegacySupport.defineLanguageSettingsEnablement(project);
 	}
 
 	/**
