@@ -649,7 +649,7 @@ public class CVisitor extends ASTQueries {
 			}
 		}
 
-		return new CBasicType(Kind.eInt, 0, expr);
+		return new CBasicType(Kind.eInt, IBasicType.IS_LONG, expr);
 	}
 
 	static IType get_SIZE_T(IASTExpression expr) {
@@ -727,8 +727,9 @@ public class CVisitor extends ASTQueries {
         boolean isFunction= false;
         if (parent instanceof IASTParameterDeclaration || parent.getPropertyInParent() == ICASTKnRFunctionDeclarator.FUNCTION_PARAMETER) {
         	IASTDeclarator fdtor = (IASTDeclarator) parent.getParent();
-        	if (ASTQueries.findTypeRelevantDeclarator(fdtor) instanceof IASTFunctionDeclarator) {
-        		IASTName n= ASTQueries.findInnermostDeclarator(fdtor).getName();
+			// Create parameter bindings only if the declarator declares a function
+        	if (ASTQueries.findTypeRelevantDeclarator(fdtor) == fdtor) {
+        		IASTName n = ASTQueries.findInnermostDeclarator(fdtor).getName();
         		IBinding temp = n.resolveBinding();
         		if (temp != null && temp instanceof CFunction) {
         			binding = ((CFunction) temp).resolveParameter(name);
