@@ -12,6 +12,7 @@
  *     Anton Leherbauer (Wind River Systems)
  *     oyvind.harboe@zylin.com - http://bugs.eclipse.org/250638
  *     Jens Elmenthaler - http://bugs.eclipse.org/173458 (camel case completion)
+ *     Sergey Prigogin (Google)
  *******************************************************************************/
 package org.eclipse.cdt.core;
 
@@ -26,6 +27,7 @@ import java.util.ResourceBundle;
 import org.eclipse.cdt.core.cdtvariables.ICdtVariableManager;
 import org.eclipse.cdt.core.cdtvariables.IUserVarSupplier;
 import org.eclipse.cdt.core.dom.IPDOMManager;
+import org.eclipse.cdt.core.dom.ast.tag.ITagService;
 import org.eclipse.cdt.core.envvar.IEnvironmentVariableManager;
 import org.eclipse.cdt.core.index.IIndexManager;
 import org.eclipse.cdt.core.language.settings.providers.ScannerDiscoveryLegacySupport;
@@ -50,6 +52,7 @@ import org.eclipse.cdt.internal.core.ICConsole;
 import org.eclipse.cdt.internal.core.PositionTrackerManager;
 import org.eclipse.cdt.internal.core.cdtvariables.CdtVariableManager;
 import org.eclipse.cdt.internal.core.cdtvariables.UserVarSupplier;
+import org.eclipse.cdt.internal.core.dom.ast.tag.TagService;
 import org.eclipse.cdt.internal.core.envvar.EnvironmentVariableManager;
 import org.eclipse.cdt.internal.core.language.settings.providers.LanguageSettingsScannerInfoProvider;
 import org.eclipse.cdt.internal.core.model.CModelManager;
@@ -89,7 +92,8 @@ import org.osgi.framework.BundleContext;
 import com.ibm.icu.text.MessageFormat;
 
 /**
- * CCorePlugin is the life-cycle owner of the core plug-in, and starting point for access to many core APIs.
+ * CCorePlugin is the life-cycle owner of the core plug-in, and starting point for access to many
+ * core APIs.
  *
  * @noextend This class is not intended to be subclassed by clients.
  * @noinstantiate This class is not intended to be instantiated by clients.
@@ -206,7 +210,7 @@ public class CCorePlugin extends Plugin {
 	/**
 	 * @noreference This field is not intended to be referenced by clients.
 	 */
-	public CDTLogWriter cdtLog = null;
+	public CDTLogWriter cdtLog;
 
 	private volatile CProjectDescriptionManager fNewCProjectDescriptionManager;
 
@@ -214,6 +218,8 @@ public class CCorePlugin extends Plugin {
 
 	private PDOMManager pdomManager;
 
+	private ITagService tagService = new TagService();
+
 	private CdtVarPathEntryVariableManager fPathEntryVariableManager;
 
 	private final class NullConsole implements IConsole {
@@ -401,7 +407,7 @@ public class CCorePlugin extends Plugin {
         HashSet<String> optionNames = CModelManager.OptionNames;
 
         // get preferences set to their default
-        for (String propertyName : preferences.defaultPropertyNames()){
+        for (String propertyName : preferences.defaultPropertyNames()) {
             if (optionNames.contains(propertyName))
                 defaultOptions.put(propertyName, preferences.getDefaultString(propertyName));
         }
@@ -429,10 +435,10 @@ public class CCorePlugin extends Plugin {
      */
     public static String getOption(String optionName) {
 
-        if (CORE_ENCODING.equals(optionName)){
+        if (CORE_ENCODING.equals(optionName)) {
             return ResourcesPlugin.getEncoding();
         }
-        if (CModelManager.OptionNames.contains(optionName)){
+        if (CModelManager.OptionNames.contains(optionName)) {
             Preferences preferences = getDefault().getPluginPreferences();
             return preferences.getString(optionName).trim();
         }
@@ -460,14 +466,14 @@ public class CCorePlugin extends Plugin {
             HashSet<String> optionNames = CModelManager.OptionNames;
 
             // get preferences set to their default
-            for (String propertyName : preferences.defaultPropertyNames()){
-                if (optionNames.contains(propertyName)){
+            for (String propertyName : preferences.defaultPropertyNames()) {
+                if (optionNames.contains(propertyName)) {
                     options.put(propertyName, preferences.getDefaultString(propertyName));
                 }
             }
             // get preferences not set to their default
-            for (String propertyName : preferences.propertyNames()){
-                if (optionNames.contains(propertyName)){
+            for (String propertyName : preferences.propertyNames()) {
+                if (optionNames.contains(propertyName)) {
                     options.put(propertyName, preferences.getString(propertyName).trim());
                 }
             }
@@ -494,10 +500,10 @@ public class CCorePlugin extends Plugin {
         // see #initializeDefaultPluginPreferences() for changing default settings
         Preferences preferences = getDefault().getPluginPreferences();
 
-        if (newOptions == null){
+        if (newOptions == null) {
             newOptions = getDefaultOptions();
         }
-        for (String key : newOptions.keySet()){
+        for (String key : newOptions.keySet()) {
             if (!CModelManager.OptionNames.contains(key)) continue; // unrecognized option
             if (key.equals(CORE_ENCODING)) continue; // skipped, contributed by resource prefs
             String value = newOptions.get(key);
@@ -713,6 +719,13 @@ public class CCorePlugin extends Plugin {
 		return getDefault().pdomManager;
 	}
 
+	/**
+	 * @since 5.5
+	 */
+	public static ITagService getTagService() {
+		return getDefault().tagService;
+	}
+
 	public IPathEntryVariableManager getPathEntryVariableManager() {
 		return fPathEntryVariableManager;
 	}
@@ -856,25 +869,25 @@ public class CCorePlugin extends Plugin {
 					// Add C Nature ... does not add duplicates
 					CProjectNature.addCNature(projectHandle, new SubProgressMonitor(monitor, 1));
 
-					if (bsId != null){
+					if (bsId != null) {
 						ICProjectDescription projDes = createProjectDescription(projectHandle, true);
 						ICConfigurationDescription cfgs[] = projDes.getConfigurations();
 						ICConfigurationDescription cfg = null;
 						for (ICConfigurationDescription cfg2 : cfgs) {
-							if (bsId.equals(cfg2.getBuildSystemId())){
+							if (bsId.equals(cfg2.getBuildSystemId())) {
 								cfg = cfg2;
 								break;
 							}
 						}
 
-						if (cfg == null){
+						if (cfg == null) {
 							ICConfigurationDescription prefCfg = getPreferenceConfiguration(bsId);
-							if (prefCfg != null){
+							if (prefCfg != null) {
 								cfg = projDes.createConfiguration(CDataUtil.genId(prefCfg.getId()), prefCfg.getName(), prefCfg);
 							}
 						}
 
-						if (cfg != null){
+						if (cfg != null) {
 							setProjectDescription(projectHandle, projDes);
 						}
 					}
@@ -1047,6 +1060,23 @@ public class CCorePlugin extends Plugin {
 		return provider;
 	}
 
+	/**
+	 * Clears cached scanner info provider for the given project so that the next call to
+	 * {@link #getScannerInfoProvider(IProject)} would return an up to date scanner info provider.
+	 *
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public void resetCachedScannerInfoProvider(IProject project) {
+		try {
+			QualifiedName scannerInfoProviderName = new QualifiedName(PLUGIN_ID, SCANNER_INFO_PROVIDER2_NAME);
+			project.setSessionProperty(scannerInfoProviderName, null);
+		} catch (CoreException e) {
+			if (project.isOpen()) {
+				log(e);
+			}
+		}
+	}
+
 	/**
 	 * Find {@link IScannerInfoProvider} registered as extension via extension point
 	 * org.eclipse.cdt.core.ScannerInfoProvider2.
@@ -1159,11 +1189,11 @@ public class CCorePlugin extends Plugin {
 	    return org.eclipse.cdt.core.dom.CDOM.getInstance();
 	}
 
-	public ICdtVariableManager getCdtVariableManager(){
+	public ICdtVariableManager getCdtVariableManager() {
 		return CdtVariableManager.getDefault();
 	}
 
-	public IEnvironmentVariableManager getBuildEnvironmentManager(){
+	public IEnvironmentVariableManager getBuildEnvironmentManager() {
 		return EnvironmentVariableManager.getDefault();
 	}
 
@@ -1221,7 +1251,7 @@ public class CCorePlugin extends Plugin {
 	 *
 	 * @see #getProjectDescription(IProject, boolean)
 	 */
-	public ICProjectDescription getProjectDescription(IProject project){
+	public ICProjectDescription getProjectDescription(IProject project) {
 		return fNewCProjectDescriptionManager.getProjectDescription(project);
 	}
 
@@ -1272,7 +1302,7 @@ public class CCorePlugin extends Plugin {
 	 * @return {@link ICProjectDescription} or null if the project does not contain the
 	 * CDT data associated with it.
 	 */
-	public ICProjectDescription getProjectDescription(IProject project, boolean write){
+	public ICProjectDescription getProjectDescription(IProject project, boolean write) {
 		return fNewCProjectDescriptionManager.getProjectDescription(project, write);
 	}
 
@@ -1292,18 +1322,18 @@ public class CCorePlugin extends Plugin {
 	/**
 	 * Answers whether the given project is a new-style project, i.e. CConfigurationDataProvider-driven
 	 */
-	public boolean isNewStyleProject(IProject project){
+	public boolean isNewStyleProject(IProject project) {
 		return fNewCProjectDescriptionManager.isNewStyleProject(project);
 	}
 
 	/**
 	 * Answers whether the given project is a new-style project, i.e. CConfigurationDataProvider-driven
 	 */
-	public boolean isNewStyleProject(ICProjectDescription des){
+	public boolean isNewStyleProject(ICProjectDescription des) {
 		return fNewCProjectDescriptionManager.isNewStyleProject(des);
 	}
 
-	public ICProjectDescriptionManager getProjectDescriptionManager(){
+	public ICProjectDescriptionManager getProjectDescriptionManager() {
 		return fNewCProjectDescriptionManager;
 	}
 
@@ -1331,6 +1361,34 @@ public class CCorePlugin extends Plugin {
 		log(createStatus(e));
 	}
 
+	/**
+	 * Print a message in the log
+	 * 
+	 * @param severity - desired severity of the message in the log,
+	 *    one of {@link IStatus#INFO}, {@link IStatus#WARNING} or {@link IStatus#ERROR}
+	 * @param msg - message
+	 * 
+	 * @since 5.5
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public static void log(int severity, String msg) {
+		log(new Status(severity, PLUGIN_ID, msg));
+	}
+	
+	/**
+	 * Print a message in the log accompanied by stack trace
+	 * 
+	 * @param severity - desired severity of the message in the log,
+	 *    one of {@link IStatus#INFO}, {@link IStatus#WARNING} or {@link IStatus#ERROR}
+	 * @param msg - message
+	 * 
+	 * @since 5.5
+	 * @noreference This method is not intended to be referenced by clients.
+	 */
+	public static void logStackTrace(int severity, String msg) {
+		log(new Status(severity, PLUGIN_ID, msg, new Exception()));
+	}
+	
 	/**
 	 * @noreference This method is not intended to be referenced by clients.
 	 */
