@@ -1,14 +1,14 @@
 /*******************************************************************************
- * Copyright (c) 2012 Ericsson and others.
+ * Copyright (c) 2010 Ericsson and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  * 
  * Contributors:
- *     Marc Khouzam (Ericsson) - Initial implementation of Test cases
+ *     Ericsson			  - Initial Implementation
  *******************************************************************************/
-package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_5;
+package org.eclipse.cdt.tests.dsf.gdb.tests.tests_7_1;
 
 import org.eclipse.cdt.dsf.mi.service.command.commands.Suite_Sessionless_Tests;
 import org.eclipse.cdt.tests.dsf.gdb.framework.BaseTestCase;
@@ -23,36 +23,37 @@ import org.junit.runners.Suite;
  * want to run.  When creating a new test class, it should be
  * added to the list below.
  * 
- * This suite is for tests to be run with GDB 7.5.
+ * This suite is for tests to be run with GDB 7.1
  */
 
 @RunWith(Suite.class)
 @Suite.SuiteClasses({
 	// We need specific name for the tests of this suite, because of bug https://bugs.eclipse.org/172256
-	GDBMultiNonStopRunControlTest_7_5.class,
-	MIRegistersTest_7_5.class,
-	MIRunControlTest_7_5.class,
-	MIRunControlTargetAvailableTest_7_5.class,
-	MIRunControlNonStopTargetAvailableTest_7_5.class,
-	MIExpressionsTest_7_5.class,
-	MIMemoryTest_7_5.class,
-	MIBreakpointsTest_7_5.class,
-	MICatchpointsTest_7_5.class,
-	MIDisassemblyTest_7_5.class,
-	GDBProcessesTest_7_5.class,
-	LaunchConfigurationAndRestartTest_7_5.class,
-	OperationsWhileTargetIsRunningTest_7_5.class,
-	OperationsWhileTargetIsRunningNonStopTest_7_5.class,
-	PostMortemCoreTest_7_5.class,
-	CommandTimeoutTest_7_5.class,
-	Suite_Sessionless_Tests.class,	
+	MIRegistersTest_7_1.class,
+	MIRunControlTest_7_1.class,
+	MIRunControlTargetAvailableTest_7_1.class,
+	MIRunControlNonStopTargetAvailableTest_7_1.class,
+	MIExpressionsTest_7_1.class,
+	GDBPatternMatchingExpressionsTest_7_1.class,
+	MIMemoryTest_7_1.class,
+	MIBreakpointsTest_7_1.class,
+	MICatchpointsTest_7_1.class,
+	MIDisassemblyTest_7_1.class,
+	GDBProcessesTest_7_1.class,
+	LaunchConfigurationAndRestartTest_7_1.class,
+	OperationsWhileTargetIsRunningTest_7_1.class,
+	OperationsWhileTargetIsRunningNonStopTest_7_1.class,
+	PostMortemCoreTest_7_1.class,
+	CommandTimeoutTest_7_1.class,
+	GDBMultiNonStopRunControlTest_7_1.class,
+	Suite_Sessionless_Tests.class,
 	/* Add your test class here */
 })
 
-public class Suite_7_5 {
+public class Suite_7_1 {
 	@BeforeClass
 	public static void beforeClassMethod() {
-		BaseTestCase.setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_5);
+		BaseTestCase.setGdbProgramNamesLaunchAttributes(ITestConstants.SUFFIX_GDB_7_1);
 		BaseTestCase.ignoreIfGDBMissing();
 	}
 }
